==> inv-api-1.4.91-nxg-20251017.090603-1-sources.jar: com/elitesland/inv/dto/invTrn/InvTrnRpcDTO.java <==
package com.elitesland.inv.dto.invTrn;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

@Data
@ApiModel(description = "库存转移详情")
public class InvTrnRpcDTO implements Serializable {

    private static final long serialVersionUID = -9066194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("转移单ID")
    private Long id;

    @ApiModelProperty("转移单号")
    private String docNo;

    @ApiModelProperty("创建日期")
    private LocalDateTime createTime;

    @ApiModelProperty("备注")
    private String remark;

    @ApiModelProperty("地址号")
    Long addrNo;

    @ApiModelProperty("承运商")
    private String carrier;

    @ApiModelProperty("配送方式")
    private String deliverMethod;

    @ApiModelProperty("物流单号")
    private String logisDocNo;

    @ApiModelProperty("调拨原因")
    private String reasonCode;

    @ApiModelProperty("结算路径正逆向")
    private Boolean saleReturnFlag;

    @ApiModelProperty("收货仓库")
    private String toWhName;

    @ApiModelProperty("收仓库编码")
    private String toWhCode;

    private Long fromWhId;

    @ApiModelProperty("收货仓库ID")
    private Long toWhId;

    @ApiModelProperty("发货仓库")
    private String fromWhName;

    @ApiModelProperty("发货仓库编码")
    private String fromWhCode;

    @ApiModelProperty("发货公司")
    private Long fromOuId;

    @ApiModelProperty("发货公司编码")
    private String fromOuCode;

    @ApiModelProperty("收货公司")
    private Long toOuId;

    @ApiModelProperty("收货公司编码")
    private String toOuCode;

    @ApiModelProperty("来源单据")
    private String relateDocCls;

    @ApiModelProperty("来源单据单号")
    private String relateDocNo;

    @ApiModelProperty("状态")
    private String docStatus;

    private List<InvTrnDRpcDTO> invTrnDRpcDTOS;
}

==> inv-api-1.5.1.3-nxg-20251208.053257-1-sources.jar: com/elitesland/inv/dto/invTrn/InvTrnRpcDTO.java <==
package com.elitesland.inv.dto.invTrn;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

@Data
@ApiModel(description = "库存转移详情")
public class InvTrnRpcDTO implements Serializable {

    private static final long serialVersionUID = -9066194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("转移单ID")
    private Long id;

    @ApiModelProperty("转移单号")
    private String docNo;

    @ApiModelProperty("创建日期")
    private LocalDateTime createTime;

    @ApiModelProperty("备注")
    private String remark;

    @ApiModelProperty("地址号")
    Long addrNo;

    @ApiModelProperty("承运商")
    private String carrier;

    @ApiModelProperty("配送方式")
    private String deliverMethod;

    @ApiModelProperty("物流单号")
    private String logisDocNo;

    @ApiModelProperty("调拨原因")
    private String reasonCode;

    @ApiModelProperty("结算路径正逆向")
    private Boolean saleReturnFlag;

    @ApiModelProperty("收货仓库")
    private String toWhName;

    @ApiModelProperty("收仓库编码")
    private String toWhCode;

    @ApiModelProperty("收货仓库类型")
    private String toWhType;

    private Long fromWhId;

    @ApiModelProperty("收货仓库ID")
    private Long toWhId;

    @ApiModelProperty("发货仓库")
    private String fromWhName;

    @ApiModelProperty("发货仓库编码")
    private String fromWhCode;

    @ApiModelProperty("发货仓库类型")
    private String fromWhType;

    @ApiModelProperty("发货公司")
    private Long fromOuId;

    @ApiModelProperty("发货公司编码")
    private String fromOuCode;

    @ApiModelProperty("收货公司")
    private Long toOuId;

    @ApiModelProperty("收货公司编码")
    private String toOuCode;

    @ApiModelProperty("来源单据")
    private String relateDocCls;

    @ApiModelProperty("来源单据单号")
    private String relateDocNo;

    @ApiModelProperty("状态")
    private String docStatus;

    @ApiModelProperty(value = "差异收货原因")
    private String returnReason;

    @ApiModelProperty(value = "差异收货图片")
    private String pics;



    private List<InvTrnDRpcDTO> invTrnDRpcDTOS;
}
